# Change Log

## 1.0.6 (2020-05-31)

* Moved repo to personal account

## 1.0.5 (2020-05-31)

* Added link to github status badge


## 1.0.4 (2020-05-31)

* Addressed problem with project description page on pypi.org


## 1.0.3 (2020-05-31)

* Restructured README.md
* Added github status badge


## 1.0.2 (2020-05-30)

* Fixed `long_description_content_type` for proper markdown render


## 1.0.1 (2020-05-30)

* Added github action in order to run tests
* Changed the README.rst to README.md
* Updated the package classifiers


## 1.0.0 (2020-05-30)

* Dropped support for Python 2.7, Python 3.4 and Pypy
* Added support for Python 3.7 and Python 3.8
* Added checker for **breakpoint()** keyword, avalaible since python 3.7


## 0.3.5 (2019-04-30)

* Dropped support for Python 3.3


## 0.3.4 (2017-02-26)

* Initial version
